local Layout = require 'lib.luigi.layout'
local Gamestate = require 'lib.hump.gamestate'

local MenuUI = require 'ui.menu'
local GameUI = require 'ui.game'
local ChoiceUI = require 'ui.choice'

local function choose (title, text, onConfirm, onCancel)
    return ChoiceUI(title, text, onConfirm, onCancel):show()
end

local player = { x = 1, y = 1 }
local beer = { x = 5, y = 5 }
local coffee = { x = 7, y = 3 }
local screenShake = 0

-- game states
local menu = {}
local game = {}

-- UI layouts
local menuUI = MenuUI(game)
local gameUI = GameUI(game, menu)

local function drinkBeer ()
    player.isDrunk = true
    gameUI.status.text = 'Drunk'
    gameUI.status.color = { 255, 0, 0 }
    screenShake = 20
end

local function drinkCoffee ()
    player.isDrunk = false
    gameUI.status.text = 'Sober'
    gameUI.status.color = { 0, 255, 0 }
end

drinkCoffee()

function game:checkBeverage ()
    if player.x == beer.x and player.y == beer.y then
        choose("Drink beer?", "You found a keg of beer. Drink some?",
            drinkBeer)
    elseif player.x == coffee.x and player.y == coffee.y then
        choose("Drink coffee?", "You found a pot of coffee. Drink some?",
            drinkCoffee)
    end
end

function game:movePlayerTo (x, y)
    player.x = x
    player.y = y
    self:checkBeverage()
end

function game:movePlayerBy (x, y)
    if player.isDrunk then x, y = x * -1, y * -1 end
    player.x = player.x + x
    player.y = player.y + y
    self:checkBeverage()
end

function menu:enter ()
    menuUI:show()
end

function menu:leave ()
    menuUI:hide()
end

function menu:draw ()
    love.graphics.print("Press S to start", 10, 400)
end

function menu:keyreleased (key, code)
    if key == 's' then
        Gamestate.switch(game)
    end
end

function game:enter ()
    gameUI:show()
end

function game:leave ()
    gameUI:hide()
end

local target = { x = 0, y = 0 }

function game:mousepressed (x, y, button)
    target = { x = math.floor(x / 50), y = math.floor(y / 50) }
    choose("Move here?", "Do you want to move here?",
        function () self:movePlayerTo(target.x, target.y) end
    ):placeNear(x, y)
end

function game:draw ()

    -- quick and dirty screen shake, should really use easing
    if screenShake ~= 0 then
        love.graphics.translate(screenShake, 0)
        screenShake = screenShake * -0.9
        if screenShake > -1 and screenShake < 1 then screenShake = 0 end
    end

    -- scale everything up 5x
    love.graphics.scale(5)

    -- draw beer
    love.graphics.setColor(192, 192, 0)
    love.graphics.rectangle('fill',
    beer.x * 10, beer.y * 10, 10, 10)

    -- draw coffee
    love.graphics.setColor(40, 40, 0)
    love.graphics.rectangle('fill',
    coffee.x * 10, coffee.y * 10, 10, 10)

    -- draw player
    love.graphics.setColor(0, 0, 255)
    love.graphics.circle('fill',
        player.x * 10 + 5, player.y * 10 + 5, 5, 16)

    -- draw target
    love.graphics.setColor(255, 0, 0)
    love.graphics.rectangle('line',
        target.x * 10, target.y * 10, 10, 10)

    -- reset transformations so they don't affect UI
    love.graphics.reset()
end

function love.load ()
    Gamestate.registerEvents()
    Gamestate.switch(menu)
end
