local Layout = require 'lib.luigi.layout'
local Gamestate = require 'lib.hump.gamestate'

return function (game, menu)
    local motion = Layout {
        { flow = 'x',
            {},
            { id = 'pause', type = 'button', text = '||', width = 36 },
        },
        {},
        { flow = 'x',
            { width = 200, height = 200,
                { flow = 'x',
                    {},
                    { id = 'up', style = 'arrow', text = '^', shortcut = 'up' },
                    {},
                },
                { flow = 'x',
                    { id = 'left', style = 'arrow', text = '<', shortcut = 'left' },
                    {},
                    { id = 'right', style = 'arrow', text = '>', shortcut = 'right' },
                },
                { flow = 'x',
                    {},
                    { id = 'down', style = 'arrow', text = 'v', shortcut = 'down' },
                    {},
                }
            },
            { id = 'status', align = 'bottom right', padding = 8, size = 24 },
        }
    }

    motion:setTheme(require 'lib.luigi.theme.dark')

    motion:setStyle {
        arrow = {
            type = 'button',
            width = false, height = false,
            align = 'middle center',
        }
    }

    motion.pause:onPress(function (event)
        if event.button ~= 'left' then return end
        Gamestate.switch(menu)
    end)

    motion.up:onPress(function (event)
        if event.button ~= 'left' then return end
        game:movePlayerBy(0, -1)
    end)

    motion.down:onPress(function (event)
        if event.button ~= 'left' then return end
        game:movePlayerBy(0, 1)
    end)

    motion.left:onPress(function (event)
        if event.button ~= 'left' then return end
        game:movePlayerBy(-1, 0)
    end)

    motion.right:onPress(function (event)
        if event.button ~= 'left' then return end
        game:movePlayerBy(1, 0)
    end)

    motion.root:onPreDisplay(function (event)
        love.graphics.setColor(255, 255, 255, 128)
    end)

    motion.root:onDisplay(function (event)
        love.graphics.reset()
    end)

    return motion
end
